
% Generates plot of welfare gains (exact, ACR, and ACDR) for changes in
% fixed cost.

global distribution

generalizedCES = 1;
distribution = 'Pareto'; % Always use Pareto distribution.

PARAMETERS

initDist; 

global f_d f_x

tau1 = tauInit;
tau2 = 0.9 * tau1;

% Fixed cost parameters
lb = 0;
ub = 3;
stepSize = 0.2;
n = round((ub-lb)/stepSize) + 1;
fs = linspace(lb, ub, n); % Vector of fixed costs
fs = [linspace(0, 0.2, 11), linspace(0.2, 0.6, 5), linspace(0.6, 3, 13)];
n = length(fs);

expenditures = zeros(2, n);
lambdajjs = zeros(2, n);
rhos = zeros(1, n);

% For each fixed cost, compute gains in welfare as tau decreases from
% tau1 to tau2.
for i = 1:n
    
    f = fs(i)
    f_d = f;
    f_x = f;
    
    [equil1, stats1] = solveEquilibrium(tau1, p_star);
    lambdajjs(1, i) = 1 - stats1.exportShare;
    rhos(i) = stats1.rho_d;
    p_star = equil1.p_star;
    
    [equil2, stats2] = solveEquilibrium(tau2, p_star);
    lambdajjs(2, i) = 1 - stats2.exportShare;
    util = calculateUtility(equil2);
    expenditures(1, i) = numericalExpenditure(equil1, util, tau1);
    expenditures(2, i) = numericalExpenditure(equil2, util, tau2);
end

dWelfareExact = expenditures(1, :) ./ expenditures(2, :);
elasticity = theta; % From Pareto distrbution
dWelfareACR = (lambdajjs(2, :)./lambdajjs(1, :)) .^ (-1./elasticity);
etas = rhos ./ (1+elasticity);
dWelfareACDR = (lambdajjs(2, :)./lambdajjs(1, :)) .^ (-(1-etas)./elasticity);

diffsACR = log(dWelfareACR./dWelfareExact);
diffsACDR = log(dWelfareACDR./dWelfareExact);

figure(1)
hold on;
X = ['Welfare Gains by f (\tau = ', num2str(tau1), ' to ', num2str(tau2), ')'];
%title(X, 'FontSize', titleSize);
xlabel('f', 'FontSize', labelSize)
ylabel('Percentage Gains', 'FontSize', labelSize)
plot(fs, (dWelfareExact-1)*100, '-k', fs, (dWelfareACR-1)*100, '--k', ...
    fs, (dWelfareACDR-1)*100, ':k', 'LineWidth', 1);
legend('Exact', 'ACR', 'ACDR');
set(gca,'YTickLabel',num2str(get(gca,'YTick').'))
hold off;

figure(2)
hold on;
title('Log differences between Exact and AC(D)R calculations', 'FontSize', titleSize);
xlabel('f', 'FontSize', labelSize)
ylabel('Relative difference (dlnW_{AC(D)R} - dlnW_{Exact})', 'FontSize', labelSize)
plot(fs, diffsACR, '--k', fs, diffsACDR, ':k', 'LineWidth', 1);
legend('ACR', 'ACDR');
set(gca,'YTickLabel',num2str(get(gca,'YTick').'))
hold off;
