
% Computes and plots markup distribution for specified baseline
% distribution, and statistics (mean and st. dev.).

[equil, stats] = solveEquilibrium(tauInit, p_star);

[markupDist, meanNex, meanEx] = computeMarkupDistributions(equil, tauInit);

% Statistics which might be useful.
meanLogMarkup = integral(@(m) log(m).*markupDist(m), 1, 1.34);
diff = meanEx - meanNex;
stdevLogMarkup = sqrt(integral(@(m) (log(m)-meanLogMarkup).^2 .* markupDist(m), 1, 1.34));

% Make histogram plot with variable bin sizes.
bins = [1 1.01 1.022 1.035 1.05 1.068 1.09 1.115 1.145 1.18 1.22 1.27 1.34];
n = length(bins);

counts = zeros(1, n-1);

endpoints = cell(n-1, 1);

for i = 1:(n-1)
    counts(i) = integral(markupDist, bins(i), bins(i+1)); % Number in bin
    endpoints{i} = num2str(bins(i+1)); % To label axis
end

figure(nFig)
hold on
set(gca, 'XTick', 1:(n-1), 'XTickLabel', endpoints);
title(['Distribution of Markups, ', distribution], 'FontSize', titleSize);
xlabel('Markup Range (right endpoint)', 'FontSize', labelSize);
ylabel('Rel. Frequency', 'FontSize', labelSize);
bar(counts);
hold off

% Plot density distribution of markups.
m_vals = linspace(0.8, 1.5, 1000);

figure(nFig+1)
hold on
title(['Distribution of Markups, ', distribution], 'FontSize', titleSize);
xlabel('Markup (labor productivity)', 'FontSize', labelSize);
ylabel('Rel. Frequency', 'FontSize', labelSize);
plot(m_vals, markupDist(m_vals));
hold off

nFig = nFig + 2;