
% Create plot of sales percentiles for all distributions.

distributions = cellstr(['Pareto          ';...
    'Truncated Pareto'; 'Log-normal      ']);
nDists = length(distributions);

salesQuantiles = cell(1, 2*nDists);
exportSalesQuantiles = cell(1, 2*nDists);
percentiles = linspace(0.02, 0.98, 50);

generalizedCES = 1;

PARAMETERS

for i = 1:3
    distribution = distributions{i}
    initDist;
    [equil, stats] = solveEquilibrium(tauInit, p_star);
    salesQuantiles{i} = salesPercentiles(equil, percentiles);
    exportSalesQuantiles{i} = salesPercentilesExporters(equil, percentiles);
end

generalizedCES = 0;

PARAMETERS

for i = 1:3
    distribution = distributions{i}
    initDist;
    [equil, stats] = solveEquilibrium(tauInit, p_star);
    salesQuantiles{i+3} = salesPercentiles(equil, percentiles);
    exportSalesQuantiles{i+3} = salesPercentilesExporters(equil, percentiles);
end

ylabels = cellstr(['0.001';'0.01 '; '0.1  '; '1    '; '10   ']);

figure(nFig)
hold on
title('Firm Sales by Percentile', 'FontSize', titleSize);
xlabel('Firm Sales Percentile', 'FontSize', labelSize);
ylabel('Sales/Mean Sales', 'FontSize', labelSize);
Dataquintiles = [.05 .25 .50 .75 .95];
DataPercmeansales = [0.00609616 0.025121586 0.093531458 0.400657323 3.363162366];
plot(percentiles.*100, salesQuantiles{1}, '-k',...
    percentiles.*100, salesQuantiles{2}, '--k',...
    percentiles.*100, salesQuantiles{3}, ':k',...
    percentiles.*100, salesQuantiles{4}, '-r',...
    percentiles.*100, salesQuantiles{5}, '--r',...
    percentiles.*100, salesQuantiles{6}, ':r', 'LineWidth', 1);
set(gca, 'yscale', 'log', 'YTickLabel', ylabels, 'YTickLabelMode', 'manual');
scatter(Dataquintiles.*100, DataPercmeansales, 's', 'filled');
legend('Pareto', 'Truncated Pareto',...
    'Log-normal', 'Pareto (CES)', 'Truncated Pareto (CES)',...
    'Log-normal (CES)', 'French Data (Mean Across Destinations)');
hold off

figure(nFig + 1)
hold on
title('Firm Sales by Percentile', 'FontSize', titleSize);
xlabel('Firm Sales Percentile', 'FontSize', labelSize);
ylabel('Sales/Mean Sales', 'FontSize', labelSize);
Dataquintiles = [.05 .25 .50 .75 .95];
DataPercmeansales = [0.00609616 0.025121586 0.093531458 0.400657323 3.363162366];
plot(percentiles.*100, salesQuantiles{1}, '-k', percentiles.*100, salesQuantiles{4}, '-r', 'LineWidth', 1);
set(gca, 'yscale', 'log', 'YTickLabel', ylabels);
scatter(Dataquintiles.*100, DataPercmeansales, 's', 'filled');
legend('Baseline Demand Estimates (with Pareto)',  'CES (with Pareto)', 'French Data (Mean Across Destinations)');
hold off