function [expenditure] = analyticExpenditure(equil, util)
% Solves for expenditure at equil (to get utility util) using analytic
% formula.

global alpha sigma g

z_d = equil.z_d;
z_x = equil.z_x;
N = equil.N;
p_d = equil.p_d;
p_x = equil.p_x;

fun1 = @(z) p_d(z).^(1-sigma) .* g(z);
fun2 = @(z) p_x(z).^(1-sigma) .* g(z);
term1 = (N * (integral(fun1, z_d, Inf) + integral(fun2, z_x, Inf))) ^ (1/(1-sigma));

term2 = (util^(1-1/sigma) + (alpha^(1-1/sigma)) * N *...
    (integral(g, z_d, Inf) + integral(g, z_x, Inf))) ^ (sigma/(sigma-1));

fun3 = @(z) p_d(z) .* g(z);
fun4 = @(z) p_x(z) .* g(z);
term3 = alpha * N * (integral(fun3, z_d, Inf) + integral(fun4, z_x, Inf));

expenditure = term1 * term2 - term3;

end

