function [rho] = calculateRho(z_star, p_star, p, tau)
% Calculates rho for a given equilibrium. We set tau=1 when computing
% rho_d, for domestic markups.

global d d_diff w z_ub g

beta = 0;
vSteps = 4000;

% Need to transform to v-space.
v_ub = log(z_ub * p_star / (w * tau));
v_vals = linspace(0, v_ub, vSteps);

v_star = log(z_star * p_star / (w * tau));
g_v = @(v) g(w .* tau ./ p_star .* exp(v));
p_v = @(v) p(z_star.*exp(v));
markup = @(v) d_diff(log(p_v(v)) - log(p_star))./(1 + d_diff(log(p_v(v)) - log(p_star)));
mu = @(v) log(markup(v));

weight = @(v) exp((1-beta).*(mu(v)) + d(mu(v)-v)) .* g_v(v);
totalArea = integral(weight, v_star, v_ub);

% Need to use interpolation to determine markup elasticity function
step = 1e-8;
d_mu_vals = (mu(v_vals+step) - mu(v_vals)) ./ step; % mu'(v)
if length(d_mu_vals) == length(v_vals)
    d_mu = @(v) interp1(v_vals, d_mu_vals, v, 'pchip', 'extrap');
    fun = @(v) d_mu(v) .* weight(v);
    rho = 1/totalArea * integral(fun, v_star, v_ub);
else % This is the CES case
    rho = 0;
end

end