function [dist, meanLogMarkupNonexporters, meanLogMarkupExporters] = computeMarkupDistributions(equil, tau)

global f_d f_x z_ub w q g

z_d = equil.z_d;
z_x = equil.z_x;
p_d = equil.p_d;
p_x = equil.p_x;
p_star = equil.p_star;

x_d = @(z) p_d(z) .* q(p_d(z), p_star); % Domestic sales by firm
x_x = @(z) p_x(z) .* q(p_x(z), p_star); % Export sales by firm

totalSales = @(z) x_d(z).*(z >= z_d) + x_x(z).*(z >= z_x);

qty_d = @(z) q(p_d(z), p_star) .* (z >= z_d);
qty_x = @(z) q(p_x(z), p_star) .*(z >= z_x);

markup = @(z) ((totalSales(z) - w.*(f_d+f_x)) ./ (w.*(qty_d(z) + tau.*qty_x(z)) ./ z));

zz = linspace(z_d, min(z_ub, 5), 400);
markupSmooth = @(z) interp1(zz, markup(zz), z, 'pchip', 1);

minMarkup = 1;
maxMarkup = max(markup(zz));

n = 100;
z_vals = zeros(1, n);
markup_vals = linspace(minMarkup, maxMarkup, n);
z0 = z_x;

for i = 1:n
    m = markup_vals(i);
    if (m == 1);
        z_vals(i) = z_d;
    else
        F = @(z) markupSmooth(z) - m;
        z_vals(i) = lsqnonlin(F, z0, z_d, z_ub, optimset('Display', 'off'));
    end
end

invMarkup = @(m) interp1(markup_vals, z_vals, m, 'pchip', 0);

area = integral(@(m) g(invMarkup(m)), minMarkup, maxMarkup);

dist = @(m) 1/area .* g(invMarkup(m));

meanLogMarkupNonexporters = integral(@(m) log(m).*dist(m), markup(z_d), markup(z_x)) ./...
    integral(dist, markup(z_d), markup(z_x));

meanLogMarkupExporters = integral(@(m) log(m).*dist(m), markup(z_x), maxMarkup) ./...
    integral(dist, markup(z_x), maxMarkup);

end

