function [p_d, p_x] = computePrices(tau, p_star)
% Returns domestic and export price functions, which are defined implicitly
% (so we solve equations on vector of points then interpolate).

global z_lb z_ub zSteps

% Generate (logarithmic) vector of points in z.
z_vals = logspace(log(z_lb)/log(10), log(z_ub)/log(10), zSteps);

% Solve for prices on z_vals.
vec_pd = priceSolver(z_vals, p_star, 1);
vec_px = priceSolver(z_vals, p_star, tau);

% Interpolate to get continuous functions.
method = 'pchip'; % Method of interpolation (pchip is piecewise cubic)

p_d = @(z) interp1(z_vals, vec_pd, z, method, 'extrap');
p_x = @(z) interp1(z_vals, vec_px, z, method, 'extrap');

end

