function [expend] = numericalExpenditure(equil, util, tau)
% Solves for expenditure using numerical procedure.

global alpha sigma z_ub g d d_diff w

z_d = equil.z_d;
z_x = equil.z_x;
N = equil.N;
p_star = equil.p_star;

u = @(d) (exp(d) + alpha).^(1 - 1/sigma) - alpha.^(1 - 1/sigma); % Utility function

% Integrals computed with respect to v = ln(z/z*).
v_ub_d = log(z_ub * p_star / w);
v_ub_x = log(z_ub * p_star / (w * tau));

v_d = log(z_d * p_star / w);
v_x = log(z_x * p_star / (w * tau));

g_d = @(v) g(w ./ p_star .* exp(v));
g_x = @(v) g(w .* tau ./ p_star .* exp(v));

p_d = @(v) equil.p_d(w ./ p_star .* exp(v));
p_x = @(v) equil.p_x(w .* tau ./ p_star .* exp(v));

markup_d = @(v) d_diff(log(p_d(v)) - log(p_star)) ./ (1 + d_diff(log(p_d(v)) - log(p_star)));
markup_x = @(v) d_diff(log(p_x(v)) - log(p_star)) ./ (1 + d_diff(log(p_x(v)) - log(p_star)));
mu_d = @(v) log(markup_d(v));
mu_x = @(v) log(markup_x(v));

% Solve for lambda (Lagrangian multiplier).
u_d = @(v, lambda) u(d(mu_d(v) - v + log(p_star) - log(lambda)));
u_x = @(v, lambda) u(d(mu_x(v) - v + log(p_star) - log(lambda)));
f1 = @(v, lambda) u_d(v, lambda) .* g_d(v) .* w ./ p_star .* exp(v);
f2 = @(v, lambda) u_x(v, lambda) .* g_x(v) .* w .* tau ./ p_star .* exp(v);
F = @(lambda) N * (integral(@(v) f1(v, lambda), v_d, v_ub_d) + integral(@(v) f2(v, lambda), v_x, v_ub_x)) - util;
lambda = fsolve(F, p_star, optimset('Display', 'off'));

% Use lambda to compute expenditure.
f3 = @(v) exp(mu_d(v)) .* exp(d(mu_d(v) - v + log(p_star) - log(lambda))) .* g_d(v);
f4 = @(v) tau .* exp(mu_x(v)) .* exp(d(mu_x(v) - v + log(p_star) - log(lambda))) .* g_x(v);
expend = N * w * (integral(f3, v_d, v_ub_d) + integral(f4, v_x, v_ub_x));

end

