function [vecPrices] = priceSolver(z_vals, p_star, tau)
% Solves for prices on vector z_vals, given p_star. (Note that tau=1 for
% domestic prices.)

global d_diff

n = size(z_vals, 2);
vecPrices = zeros(1, n);

% We input the previous solution to speed things up. Can't start at p*
% because function is undefined there.
prev_sol = p_star - 0.01;

for i = 1:n
    z = z_vals(i);
    f = @(p) d_diff(log(p) - log(p_star))/(1 + d_diff(log(p) - log(p_star))) .* tau/z - p;
    vecPrices(i) = fsolve(f, prev_sol, optimset('Display', 'off'));
    prev_sol = vecPrices(i);
end

end

