function [quantileSales] = salesPercentiles(equil, percentiles)
% Generates the sales (relative to total mean sales) that correspond to
% each percentile of interest, for a given equilibrium.

global g q

z_d = equil.z_d;
z_x = equil.z_x;

p_d = equil.p_d;
p_x = equil.p_x;
p_star = equil.p_star;

x_d = @(z) p_d(z) .* q(p_d(z), p_star); % Domestic sales by firm
x_x = @(z) p_x(z) .* q(p_x(z), p_star); % Export sales by firm

totalSales = @(z) x_d(z).*(z >= z_d) + x_x(z).*(z >= z_x);

n = length(percentiles);
producing = integral(g, z_d, Inf); % Total number (measure) of firms that are producing.
z0 = z_d;
xx = zeros(1, n);

% Find value of z corresponding to each percentile of interest (solve for
% upper bound of integral that gives the correct fraction of firms), and
% totalSales at that percentile.
for i = 1:n
    F = @(z) 1/producing * integral(g, z_d, z) - percentiles(i);
    z = fsolve(F, z0, optimset('Display','off'));
    z0 = z;
    xx(i) = totalSales(z);
end

meanSales = 1/producing * integral(@(z) totalSales(z).*g(z), z_d, Inf);

quantileSales = xx ./ meanSales;

end

