function [quantileSales] = salesPercentilesExporters(equil, percentiles)
% Generates the export sales (relative to mean export sales) that
% correspond to each percentile of interest, for a given equilibrium.
% Identical to salesPercentiles.m, but only includes exporting firms.

global g q

z_d = equil.z_d;
z_x = equil.z_x;

p_d = equil.p_d;
p_x = equil.p_x;
p_star = equil.p_star;

x_x = @(z) p_x(z) .* q(p_x(z), p_star); % Export sales by firm

n = length(percentiles);
exporting = integral(g, z_x, Inf); % Total number (measure) of firms that are exporting.
z0 = z_x;
xx = zeros(1, n);

% Find value of z corresponding to each percentile of interest (solve for
% upper bound of integral that gives the correct fraction of firms), and
% export sales at that percentile.
for i = 1:n
    F = @(z) 1/exporting * integral(g, z_x, z) - percentiles(i);
    z = fsolve(F, z0, optimset('Display','off'));
    z0 = z;
    xx(i) = x_x(z);
end

meanSales = 1/exporting * integral(@(z) x_x(z).*g(z), z_x, Inf);

quantileSales = xx ./ meanSales;

end

